# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.rules import delivery_shipper_pb2 as v1_dot_rules_dot_delivery__shipper__pb2


class DeliveryShipperServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DeliveryShipperCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_shipper.DeliveryShipperService/DeliveryShipperCreate",
            request_serializer=v1_dot_rules_dot_delivery__shipper__pb2.DeliveryShipperCreateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__shipper__pb2.DeliveryShipperCreateResponse.FromString,
        )
        self.DeliveryShipperRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_shipper.DeliveryShipperService/DeliveryShipperRead",
            request_serializer=v1_dot_rules_dot_delivery__shipper__pb2.DeliveryShipperReadRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__shipper__pb2.DeliveryShipperReadResponse.FromString,
        )
        self.DeliveryShipperUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_shipper.DeliveryShipperService/DeliveryShipperUpdate",
            request_serializer=v1_dot_rules_dot_delivery__shipper__pb2.DeliveryShipperUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__shipper__pb2.DeliveryShipperUpdateResponse.FromString,
        )
        self.DeliveryShipperDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_shipper.DeliveryShipperService/DeliveryShipperDelete",
            request_serializer=v1_dot_rules_dot_delivery__shipper__pb2.DeliveryShipperDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__shipper__pb2.DeliveryShipperDeleteResponse.FromString,
        )


class DeliveryShipperServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def DeliveryShipperCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryShipperRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryShipperUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryShipperDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_DeliveryShipperServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "DeliveryShipperCreate": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryShipperCreate,
            request_deserializer=v1_dot_rules_dot_delivery__shipper__pb2.DeliveryShipperCreateRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__shipper__pb2.DeliveryShipperCreateResponse.SerializeToString,
        ),
        "DeliveryShipperRead": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryShipperRead,
            request_deserializer=v1_dot_rules_dot_delivery__shipper__pb2.DeliveryShipperReadRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__shipper__pb2.DeliveryShipperReadResponse.SerializeToString,
        ),
        "DeliveryShipperUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryShipperUpdate,
            request_deserializer=v1_dot_rules_dot_delivery__shipper__pb2.DeliveryShipperUpdateRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__shipper__pb2.DeliveryShipperUpdateResponse.SerializeToString,
        ),
        "DeliveryShipperDelete": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryShipperDelete,
            request_deserializer=v1_dot_rules_dot_delivery__shipper__pb2.DeliveryShipperDeleteRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__shipper__pb2.DeliveryShipperDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.rules.delivery_shipper.DeliveryShipperService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class DeliveryShipperService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def DeliveryShipperCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_shipper.DeliveryShipperService/DeliveryShipperCreate",
            v1_dot_rules_dot_delivery__shipper__pb2.DeliveryShipperCreateRequest.SerializeToString,
            v1_dot_rules_dot_delivery__shipper__pb2.DeliveryShipperCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryShipperRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_shipper.DeliveryShipperService/DeliveryShipperRead",
            v1_dot_rules_dot_delivery__shipper__pb2.DeliveryShipperReadRequest.SerializeToString,
            v1_dot_rules_dot_delivery__shipper__pb2.DeliveryShipperReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryShipperUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_shipper.DeliveryShipperService/DeliveryShipperUpdate",
            v1_dot_rules_dot_delivery__shipper__pb2.DeliveryShipperUpdateRequest.SerializeToString,
            v1_dot_rules_dot_delivery__shipper__pb2.DeliveryShipperUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryShipperDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_shipper.DeliveryShipperService/DeliveryShipperDelete",
            v1_dot_rules_dot_delivery__shipper__pb2.DeliveryShipperDeleteRequest.SerializeToString,
            v1_dot_rules_dot_delivery__shipper__pb2.DeliveryShipperDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )
